use <../libs/rounded_shapes.scad>

$fn = 44;

psu_width = 126.0;
psu_height = 67.1;

wall_thickness = 1.95;

base_thickness = 3.0;

internal_space = 25.4 * 1.5;
mount_depth = 40.0 + internal_space;

fitment_tolerance = 0.5;

left_tab_width = 10.0;
bottom_hole_dia = 11/64.0 * 25.4;
left_hole_offset = left_tab_width/2.0;

bottom_holes_gap = 102.0;
right_hole_offset = left_tab_width + bottom_holes_gap + (left_tab_width/2.0);

side_hole_depth = 31.5;
side_hole_height = 30.0;
side_hole_dia = 5.0; 

wires_slot_width = 25.4 * 1.5;
wires_slot_height = 25.4 * (3/8.0);

ac_connector_width = 27.5;
ac_connector_height = 49/64.0 * 25.4;

ac_connector_mounting_hole_dia = 9/64.0 * 25.4;
ac_connector_mounting_hole_space = 44.0 - ac_connector_mounting_hole_dia;
ac_connector_fitment_pct = 1.1;

power_switch_radius = 12/2 * 1.09;

foot_dim = 18;
foot_rounding_radius = 3.0;

mount_screw_dia = 11/64.0 * 25.4;
mount_screw_hole_radius = mount_screw_dia * 1.04 / 2.0;

lid_screw_dia = 2.981 * 0.95; 
post_dim = 5.0;

relay_depth = 19.1;
relay_width = 15.5;
relay_height = 11.1;
relay_holder_border_width = 0.7;

module relay_holder() { 
  difference(){
    cube([relay_width + relay_holder_border_width * 2, relay_depth + relay_holder_border_width * 2, relay_height * (3/8)]);
    translate([relay_holder_border_width, relay_holder_border_width,0]){
      cube([relay_width, relay_depth, relay_height * 2]);
    }
  }
}

module mounting_foot(){
  difference(){
    union(){
      rounded_rectangle(foot_dim, foot_dim, base_thickness, foot_rounding_radius);
      translate([foot_dim - foot_rounding_radius - post_dim,0,base_thickness]){        
        difference(){
          cube([post_dim, post_dim, psu_height]);
          translate([post_dim/2.0, post_dim/2.0, psu_height * (2/3.0)]){
            cylinder(r = lid_screw_dia/2.0, h = psu_height);
          }
        }
      }
    }
    translate([foot_dim * (1/3.0),foot_dim/2.0,-1]){
      cylinder(r = mount_screw_hole_radius, h = base_thickness * 2);
    }
  }
}

difference() {
  // Make the basic case with 3 sides
  union(){
    translate([-1 * foot_dim + foot_rounding_radius, 0, 0]){
      mounting_foot();
      translate([0, mount_depth - foot_dim + wall_thickness, 0]){
        mounting_foot();
      }
    }
    translate([psu_width + wall_thickness * 2 + fitment_tolerance + foot_dim - foot_rounding_radius, foot_dim, 0]){
      rotate([0,0,180]){
        mounting_foot();
      }
      translate([0, mount_depth + wall_thickness - foot_dim,0]){
        rotate([0,0,180]){
          mounting_foot();
        }
      }
    }
  cube([psu_width + fitment_tolerance + wall_thickness *2, mount_depth + wall_thickness, base_thickness]);
  translate([wall_thickness + ac_connector_mounting_hole_space + 14,wall_thickness +3,base_thickness]){
    color("red") relay_holder();
 }
    
  translate([0, wall_thickness,base_thickness]){
    cube([wall_thickness, mount_depth, psu_height]); // left wall
     
    translate([wall_thickness + fitment_tolerance + psu_width, 0,0]){
      difference(){
        union(){
          cube([wall_thickness, mount_depth, psu_height]); // right wall
          translate([wall_thickness, mount_depth - 13, side_hole_height - 5]){
            cube([post_dim, 13, 10]);
          }
        }
        translate([-1, side_hole_depth + internal_space, side_hole_height]){
          rotate([0,90,0]){
            cylinder(r = side_hole_dia/2.0 * 1.185, h = wall_thickness * 10);
          }
        }
      }
      
    }
    
  }
  translate([0,0,base_thickness]){
    cube([psu_width + fitment_tolerance + wall_thickness * 2, wall_thickness, psu_height]); // front wall
  }
  }
  
  // Hole for mounting on bottom left
  translate([wall_thickness + left_hole_offset, internal_space, -1.0]){
    cylinder(r = bottom_hole_dia/2.0 * 1.125, h = base_thickness * 2);
  }
  
  // Hole for mounting on bottom right
  translate([wall_thickness + right_hole_offset, internal_space, -1.0]){
    cylinder(r = bottom_hole_dia/2.0 * 1.125, h = base_thickness * 2);
  }
  
  // Hole for DC wires  
  translate([psu_width * (12/20.0)  + wall_thickness, -1, base_thickness * 1.5]){    
    union(){
      translate([0, 0, wires_slot_height/2.0]){
        rotate([-90,0,0]){
          cylinder(r = wires_slot_height/2.0, h = wall_thickness * 3.0);
        }
      }
      cube([wires_slot_width, wall_thickness * 2, wires_slot_height]);      
      translate([wires_slot_width, 0, wires_slot_height/2.0]){
        rotate([-90,0,0]){
          cylinder(r = wires_slot_height/2.0, h = wall_thickness * 3.0);
        }
      }
    }    
  }
  
  // Hole for AC connector
  translate([wall_thickness*5, -1, base_thickness * 2]){    
    translate([ac_connector_width * (1/3.0) + 3,0,ac_connector_height + 1.55 * power_switch_radius * 2]){
      rotate([-90, 0, 0]){
        cylinder( r = power_switch_radius, h = wall_thickness * 2);
      }
    }
    translate([(ac_connector_width * ac_connector_fitment_pct)/2.0, 0, ac_connector_height * ac_connector_fitment_pct * 0.5]){
      translate([ac_connector_mounting_hole_space/2, 0, 0]){
        rotate([-90,0,0]){
          cylinder(r = ac_connector_mounting_hole_dia / 2.0 * 1.1, h = wall_thickness * 2);
        }
      }
      translate([-1 * ac_connector_mounting_hole_space/2, 0, 0]){
        rotate([-90,0,0]){
          cylinder(r = ac_connector_mounting_hole_dia / 2.0 * 1.1, h = wall_thickness * 2);
        }
      }
    }
    cube([ac_connector_width * ac_connector_fitment_pct, wall_thickness * 2, ac_connector_height * ac_connector_fitment_pct]);
  }
  
}